@@ -32,10 +32,6 @@ class Akismet_Admin {
 		if ( isset( $_POST['action'] ) && $_POST['action'] == 'enter-key' ) {
 			self::enter_api_key();
 		}
-
-		if ( ! empty( $_GET['akismet_comment_form_privacy_notice'] ) && empty( $_GET['settings-updated']) ) {
-			self::set_form_privacy_notice_option( $_GET['akismet_comment_form_privacy_notice'] );
-		}
 	}
 
 	public static function init_hooks() {
@@ -70,16 +66,18 @@ class Akismet_Admin {
 		
 		add_filter( 'all_plugins', array( 'Akismet_Admin', 'modify_plugin_description' ) );
 
-		if ( class_exists( 'Jetpack' ) ) {
-			add_filter( 'akismet_comment_form_privacy_notice_url_display',  array( 'Akismet_Admin', 'jetpack_comment_form_privacy_notice_url' ) );
-			add_filter( 'akismet_comment_form_privacy_notice_url_hide',     array( 'Akismet_Admin', 'jetpack_comment_form_privacy_notice_url' ) );
-		}
-
 		// priority=1 because we need ours to run before core's comment anonymizer runs, and that's registered at priority=10
 		add_filter( 'wp_privacy_personal_data_erasers', array( 'Akismet_Admin', 'register_personal_data_eraser' ), 1 );
 	}
 
 	public static function admin_init() {
+		if ( get_option( 'Activated_Akismet' ) ) {
+			delete_option( 'Activated_Akismet' );
+			if ( ! headers_sent() ) {
+				wp_redirect( add_query_arg( array( 'page' => 'akismet-key-config', 'view' => 'start' ), class_exists( 'Jetpack' ) ? admin_url( 'admin.php' ) : admin_url( 'options-general.php' ) ) );
+			}
+		}
+
 		load_plugin_textdomain( 'akismet' );
 		add_meta_box( 'akismet-status', __('Comment History', 'akismet'), array( 'Akismet_Admin', 'comment_status_meta_box' ), 'comment', 'normal' );
 
@@ -139,7 +137,7 @@ class Akismet_Admin {
 
 			wp_register_script( 'akismet.js', plugin_dir_url( __FILE__ ) . '_inc/akismet.js', array('jquery'), AKISMET_VERSION );
 			wp_enqueue_script( 'akismet.js' );
-			
+		
 			$inline_js = array(
 				'comment_author_url_nonce' => wp_create_nonce( 'comment_author_url_nonce' ),
 				'strings' => array(
@@ -155,6 +153,10 @@ class Akismet_Admin {
 				$inline_js['start_recheck'] = true;
 			}
 
+			if ( apply_filters( 'akismet_enable_mshots', true ) ) {
+				$inline_js['enable_mshots'] = true;
+			}
+
 			wp_localize_script( 'akismet.js', 'WPAkismet', $inline_js );
 		}
 	}
@@ -385,25 +387,40 @@ class Akismet_Admin {
 			return;
 		}
 
-		$link = add_query_arg( array( 'action' => 'akismet_recheck_queue' ), admin_url( 'admin.php' ) );
+		$link = '';
 
 		$comments_count = wp_count_comments();
 		
 		echo '</div>';
-		echo '<div class="alignleft">';
-		echo '<a
-				class="button-secondary checkforspam"
-				href="' . esc_url( $link ) . '"
-				data-active-label="' . esc_attr( __( 'Checking for Spam', 'akismet' ) ) . '"
-				data-progress-label-format="' . esc_attr( __( '(%1$s%)', 'akismet' ) ) . '"
-				data-success-url="' . esc_attr( remove_query_arg( 'akismet_recheck', add_query_arg( array( 'akismet_recheck_complete' => 1, 'recheck_count' => urlencode( '__recheck_count__' ), 'spam_count' => urlencode( '__spam_count__' ) ) ) ) ) . '"
-				data-pending-comment-count="' . esc_attr( $comments_count->moderated ) . '"
-				>';
-			echo '<span class="akismet-label">' . esc_html__('Check for Spam', 'akismet') . '</span>';
-			echo '<span class="checkforspam-progress"></span>';
-		echo '</a>';
-		echo '<span class="checkforspam-spinner"></span>';
+		echo '<div class="alignleft actions">';
 
+		$classes = array(
+			'button-secondary',
+			'checkforspam',
+			'button-disabled'	// Disable button until the page is loaded
+		);
+
+		if ( $comments_count->moderated > 0 ) {
+			$classes[] = 'enable-on-load';
+
+			if ( ! Akismet::get_api_key() ) {
+				$link = add_query_arg( array( 'page' => 'akismet-key-config' ), class_exists( 'Jetpack' ) ? admin_url( 'admin.php' ) : admin_url( 'options-general.php' ) );
+				$classes[] = 'ajax-disabled';
+			}
+		}
+
+		echo '<a
+				class="' . esc_attr( implode( ' ', $classes ) ) . '"' .
+				( ! empty( $link ) ? ' href="' . esc_url( $link ) . '"' : '' ) .
+				/* translators: The placeholder is for showing how much of the process has completed, as a percent. e.g., "Checking for Spam (40%)" */
+				' data-progress-label="' . esc_attr( __( 'Checking for Spam (%1$s%)', 'akismet' ) ) . '"
+				data-success-url="' . esc_attr( remove_query_arg( array( 'akismet_recheck', 'akismet_recheck_error' ), add_query_arg( array( 'akismet_recheck_complete' => 1, 'recheck_count' => urlencode( '__recheck_count__' ), 'spam_count' => urlencode( '__spam_count__' ) ) ) ) ) . '"
+				data-failure-url="' . esc_attr( remove_query_arg( array( 'akismet_recheck', 'akismet_recheck_complete' ), add_query_arg( array( 'akismet_recheck_error' => 1 ) ) ) ) . '"
+				data-pending-comment-count="' . esc_attr( $comments_count->moderated ) . '"
+				data-nonce="' . esc_attr( wp_create_nonce( 'akismet_check_for_spam' ) ) . '"
+				' . ( ! in_array( 'ajax-disabled', $classes ) ? 'onclick="return false;"' : '' ) . '
+				>' . esc_html__('Check for Spam', 'akismet') . '</a>';
+		echo '<span class="checkforspam-spinner"></span>';
 	}
 
 	public static function recheck_queue() {
@@ -414,6 +431,13 @@ class Akismet_Admin {
 		if ( ! ( isset( $_GET['recheckqueue'] ) || ( isset( $_REQUEST['action'] ) && 'akismet_recheck_queue' == $_REQUEST['action'] ) ) ) {
 			return;
 		}
+		
+		if ( ! wp_verify_nonce( $_POST['nonce'], 'akismet_check_for_spam' ) ) {
+			wp_send_json( array(
+				'error' => __( "You don't have permission to do that."),
+			));
+			return;
+		}
 
 		$result_counts = self::recheck_queue_portion( empty( $_POST['offset'] ) ? 0 : $_POST['offset'], empty( $_POST['limit'] ) ? 100 : $_POST['limit'] );
 
@@ -559,10 +583,8 @@ class Akismet_Admin {
 		$history = Akismet::get_comment_history( $comment->comment_ID );
 
 		if ( $history ) {
-			echo '<div class="akismet-history" style="margin: 13px;">';
-
 			foreach ( $history as $row ) {
-				$time = date( 'D d M Y @ h:i:m a', $row['time'] ) . ' GMT';
+				$time = date( 'D d M Y @ h:i:s a', $row['time'] ) . ' GMT';
 				
 				$message = '';
 				
@@ -572,56 +594,67 @@ class Akismet_Admin {
 					// 1) Save space.
 					// 2) The message can be translated into the current language of the blog, not stuck 
 					//    in the language of the blog when the comment was made.
-					$message = $row['message'];
+					$message = esc_html( $row['message'] );
 				}
 				
 				// If possible, use a current translation.
 				switch ( $row['event'] ) {
 					case 'recheck-spam';
-						$message = __( 'Akismet re-checked and caught this comment as spam.', 'akismet' );
+						$message = esc_html( __( 'Akismet re-checked and caught this comment as spam.', 'akismet' ) );
 					break;
 					case 'check-spam':
-						$message = __( 'Akismet caught this comment as spam.', 'akismet' );
+						$message = esc_html( __( 'Akismet caught this comment as spam.', 'akismet' ) );
 					break;
 					case 'recheck-ham':
-						$message = __( 'Akismet re-checked and cleared this comment.', 'akismet' );
+						$message = esc_html( __( 'Akismet re-checked and cleared this comment.', 'akismet' ) );
 					break;
 					case 'check-ham':
-						$message = __( 'Akismet cleared this comment.', 'akismet' );
+						$message = esc_html( __( 'Akismet cleared this comment.', 'akismet' ) );
 					break;
 					case 'wp-blacklisted':
-						$message = __( 'Comment was caught by wp_blacklist_check.', 'akismet' );
+					case 'wp-disallowed':
+						$message = sprintf(
+							/* translators: The placeholder is a WordPress PHP function name. */
+							esc_html( __( 'Comment was caught by %s.', 'akismet' ) ),
+							function_exists( 'wp_check_comment_disallowed_list' ) ? '<code>wp_check_comment_disallowed_list</code>' : '<code>wp_blacklist_check</code>'
+						);
 					break;
 					case 'report-spam':
 						if ( isset( $row['user'] ) ) {
-							$message = sprintf( __( '%s reported this comment as spam.', 'akismet' ), $row['user'] );
+							$message = esc_html( sprintf( __( '%s reported this comment as spam.', 'akismet' ), $row['user'] ) );
 						}
 						else if ( ! $message ) {
-							$message = __( 'This comment was reported as spam.', 'akismet' );
+							$message = esc_html( __( 'This comment was reported as spam.', 'akismet' ) );
 						}
 					break;
 					case 'report-ham':
 						if ( isset( $row['user'] ) ) {
-							$message = sprintf( __( '%s reported this comment as not spam.', 'akismet' ), $row['user'] );
+							$message = esc_html( sprintf( __( '%s reported this comment as not spam.', 'akismet' ), $row['user'] ) );
 						}
 						else if ( ! $message ) {
-							$message = __( 'This comment was reported as not spam.', 'akismet' );
+							$message = esc_html( __( 'This comment was reported as not spam.', 'akismet' ) );
 						}
 					break;
 					case 'cron-retry-spam':
-						$message = __( 'Akismet caught this comment as spam during an automatic retry.' , 'akismet');
+						$message = esc_html( __( 'Akismet caught this comment as spam during an automatic retry.' , 'akismet') );
 					break;
 					case 'cron-retry-ham':
-						$message = __( 'Akismet cleared this comment during an automatic retry.', 'akismet');
+						$message = esc_html( __( 'Akismet cleared this comment during an automatic retry.', 'akismet') );
 					break;
 					case 'check-error':
 						if ( isset( $row['meta'], $row['meta']['response'] ) ) {
-							$message = sprintf( __( 'Akismet was unable to check this comment (response: %s) but will automatically retry later.', 'akismet'), $row['meta']['response'] );
+							$message = sprintf( esc_html( __( 'Akismet was unable to check this comment (response: %s) but will automatically retry later.', 'akismet') ), '<code>' . esc_html( $row['meta']['response'] ) . '</code>' );
+						}
+						else {
+							$message = esc_html( __( 'Akismet was unable to check this comment but will automatically retry later.', 'akismet' ) );
 						}
 					break;
 					case 'recheck-error':
 						if ( isset( $row['meta'], $row['meta']['response'] ) ) {
-							$message = sprintf( __( 'Akismet was unable to recheck this comment (response: %s).', 'akismet'), $row['meta']['response'] );
+							$message = sprintf( esc_html( __( 'Akismet was unable to recheck this comment (response: %s).', 'akismet') ), '<code>' . esc_html( $row['meta']['response'] ) . '</code>' );
+						}
+						else {
+							$message = esc_html( __( 'Akismet was unable to recheck this comment.', 'akismet' ) );
 						}
 					break;
 					default:
@@ -629,27 +662,32 @@ class Akismet_Admin {
 							// Half of these used to be saved without the dash after 'status-changed'.
 							// See https://plugins.trac.wordpress.org/changeset/1150658/akismet/trunk
 							$new_status = preg_replace( '/^status-changed-?/', '', $row['event'] );
-							$message = sprintf( __( 'Comment status was changed to %s', 'akismet' ), $new_status );
+							$message = sprintf( esc_html( __( 'Comment status was changed to %s', 'akismet' ) ), '<code>' . esc_html( $new_status ) . '</code>' );
 						}
 						else if ( preg_match( '/^status-/', $row['event'] ) ) {
 							$new_status = preg_replace( '/^status-/', '', $row['event'] );
 
 							if ( isset( $row['user'] ) ) {
-								$message = sprintf( __( '%1$s changed the comment status to %2$s.', 'akismet' ), $row['user'], $new_status );
+								$message = sprintf( esc_html( __( '%1$s changed the comment status to %2$s.', 'akismet' ) ), $row['user'], '<code>' . esc_html( $new_status ) . '</code>' );
 							}
 						}
 					break;
 					
 				}
 
-				echo '<div style="margin-bottom: 13px;">';
+				if ( ! empty( $message ) ) {
+					echo '<p>';
 					echo '<span style="color: #999;" alt="' . $time . '" title="' . $time . '">' . sprintf( esc_html__('%s ago', 'akismet'), human_time_diff( $row['time'] ) ) . '</span>';
 					echo ' - ';
-					echo esc_html( $message );
-				echo '</div>';
+					echo $message; // esc_html() is done above so that we can use HTML in some messages.
+					echo '</p>';
+				}
 			}
-
-			echo '</div>';
+		}
+		else {
+			echo '<p>';
+			echo esc_html( __( 'No comment history.', 'akismet' ) );
+			echo '</p>';
 		}
 	}
 
@@ -850,14 +888,6 @@ class Akismet_Admin {
 		) );
 	}
 
-	public static function display_privacy_notice_control_warning() {
-		if ( !current_user_can( 'manage_options' ) )
-			return;
-		Akismet::view( 'notice', array(
-			'type' => 'privacy',
-		) );
-	}
-
 	public static function display_spam_check_warning() {
 		Akismet::fix_scheduled_recheck();
 
@@ -991,10 +1021,6 @@ class Akismet_Admin {
 			$notices[] = array( 'type' => $akismet_user->status );
 		}
 
-		if ( false === get_option( 'akismet_comment_form_privacy_notice' ) ) {
-			$notices[] = array( 'type' => 'privacy' );
-		}
-
 		/*
 		// To see all variants when testing.
 		$notices[] = array( 'type' => 'active-notice', 'time_saved' => 'Cleaning up spam takes time. Akismet has saved you 1 minute!' );
@@ -1034,18 +1060,20 @@ class Akismet_Admin {
 			if ( get_option( 'akismet_alert_code' ) > 0 )
 				self::display_alert();
 		}
-		elseif ( $hook_suffix == 'plugins.php' && !Akismet::get_api_key() ) {
+		elseif ( ( 'plugins.php' === $hook_suffix || 'edit-comments.php' === $hook_suffix ) && ! Akismet::get_api_key() ) {
+			// Show the "Set Up Akismet" banner on the comments and plugin pages if no API key has been set.
 			self::display_api_key_warning();
 		}
 		elseif ( $hook_suffix == 'edit-comments.php' && wp_next_scheduled( 'akismet_schedule_cron_recheck' ) ) {
 			self::display_spam_check_warning();
 		}
-		else if ( isset( $_GET['akismet_recheck_complete'] ) ) {
+		
+		if ( isset( $_GET['akismet_recheck_complete'] ) ) {
 			$recheck_count = (int) $_GET['recheck_count'];
 			$spam_count = (int) $_GET['spam_count'];
 			
 			if ( $recheck_count === 0 ) {
-				$message = __( 'There were no comments to check. Akismet will only check comments in the Pending queue.', 'akismet' );
+				$message = __( 'There were no comments to check. Akismet will only check comments awaiting moderation.', 'akismet' );
 			}
 			else {
 				$message = sprintf( _n( 'Akismet checked %s comment.', 'Akismet checked %s comments.', $recheck_count, 'akismet' ), number_format( $recheck_count ) );
@@ -1061,13 +1089,8 @@ class Akismet_Admin {
 			
 			echo '<div class="notice notice-success"><p>' . esc_html( $message ) . '</p></div>';
 		}
-
-		$akismet_comment_form_privacy_notice_option = get_option( 'akismet_comment_form_privacy_notice' );
-		if ( ! in_array( $akismet_comment_form_privacy_notice_option, array( 'hide', 'display' ) ) ) {
-			$api_key = Akismet::get_api_key();
-			if ( ! empty( $api_key ) ) {
-				self::display_privacy_notice_control_warning();
-			}
+		else if ( isset( $_GET['akismet_recheck_error'] ) ) {
+			echo '<div class="notice notice-error"><p>' . esc_html( __( 'Akismet could not recheck your comments for spam.', 'akismet' ) ) . '</p></div>';
 		}
 	}
 
@@ -1108,7 +1131,11 @@ class Akismet_Admin {
 		if ( !class_exists('Jetpack') )
 			return false;
 
-		Jetpack::load_xml_rpc_client();
+		if ( defined( 'JETPACK__VERSION' ) && version_compare( JETPACK__VERSION, '7.7', '<' )  ) {
+			// For version of Jetpack prior to 7.7.
+			Jetpack::load_xml_rpc_client();
+		}
+
 		$xml = new Jetpack_IXR_ClientMulticall( array( 'user_id' => get_current_user_id() ) );
 
 		$xml->addCall( 'wpcom.getUserID' );
@@ -1179,10 +1206,6 @@ class Akismet_Admin {
 			update_option( 'akismet_comment_form_privacy_notice', $state );
 		}
 	}
-
-	public static function jetpack_comment_form_privacy_notice_url( $url ) {
-		return str_replace( 'options-general.php', 'admin.php', $url );
-	}
 	
 	public static function register_personal_data_eraser( $erasers ) {
 		$erasers['akismet'] = array(
